  <div class="content-wrapper">
    <!-- Content Header (Page header) -->
    <section class="content-header">
      <div class="container-fluid">
        <div class="row mb-2">
          <div class="col-sm-6">
            <h1>Búsqueda de Documentos</h1>
          </div>
          <div class="col-sm-6">
            <ol class="breadcrumb float-sm-right">
              <li class="breadcrumb-item"><a href="#">Home</a></li>
              <li class="breadcrumb-item"><a href="#">Administracion</a></li>
              <li class="breadcrumb-item"><a href="#">Gestión documental</a></li>
              <li class="breadcrumb-item active">Búsqueda de Documentos</li>
            </ol>
          </div>
        </div>
      </div><!-- /.container-fluid -->
    </section>

    <!-- Modal documentos -->
    <div class="modal fade" id="id_documento" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true">
      <div class="modal-dialog modal-lg">
        <div class="modal-content">
          <div class="modal-header">
            <h5 class="modal-title" id="exampleModalLabel">Crear nuevo documento</h5>   
          </div>
          <div class="modal-body">
            <form class="form-horizontal" autocomplete="off"> 
              <div class="row">
                  <div class="form-group col-sm-6">
                    <select class="form-control" name="tipodocumento" id="tipodocumento">
                      <option>TIPO DE DOCUMENTO</option>
                    </select>
                  </div>
                  <div class="form-group col-sm-6">
                    <input type="text" class="form-control" name="nombredocumento" id="nombredocumento" placeholder="NOMBRE DE DOCUMENTO">
                  </div>
                  <div class="form-group col-sm-12">
                    <textarea class="form-control" rows="3" name="descripciondocumento" id="descripciondocumento" placeholder="DESCRIPCIÓN DE DOCUMENTO"></textarea>
                  </div>
                  <div class="form-group col-sm-6">
                    <select class="form-control" name="proceso_" id="proceso_">
                      <option>PROCESO</option>
                    </select>
                  </div>
                  <div class="form-group col-sm-6">
                    <select class="form-control" name="estado" id="estado">
                      <option>ESTADO</option>
                    </select>
                  </div>
                  <div class="input-group mb-3 col-sm-6">
                    <div class="custom-file">
                      <input type="file" class="custom-file-input" id="inputGroupFile03" aria-describedby="inputGroupFileAddon03">
                      <label class="custom-file-label" for="inputGroupFile03">ADJUNTAR DOCUMENTO</label>
                    </div>
                  </div>
                  <div class="form-group col-sm-6">
                    <select class="form-control" name="estado" id="estado">
                      <option>ACCESO</option>
                      <option value="1">SI</option>
                      <option value="0">NO</option>
                    </select>
                  </div>
              </div>
            </form>
          </div>
          <div class="modal-footer">
            <button type="button" class="btn btn-success" data-dismiss="modal">Cerrar <i class="fas fa-times ml-3"></i></button>
            <button type="button" class="btn btn-success">Guardar <i class="far fa-save ml-3"></i></button>
          </div>
        </div>
      </div>
    </div>

    <!-- Main content -->
    <section class="content">

      <div class="container-fluid">
        <div class="row">
          <div class="col-12">
            <!-- Default box -->
            <div class="card">
              <!-- <div class="card-header">
                <h3 class="card-title">Opción no disponible</h3>

                <div class="card-tools">
                  <button type="button" class="btn btn-tool" data-card-widget="collapse" data-toggle="tooltip" title="Collapse">
                    <i class="fas fa-minus"></i></button>
                  <button type="button" class="btn btn-tool" data-card-widget="remove" data-toggle="tooltip" title="Remove">
                    <i class="fas fa-times"></i></button>
                </div>
              </div> -->
              <form class="form-horizontal" action="" method="post" autocomplete="off" id="frm_edicion_documento">  
                <div class="card-body">
                  <?php 

                    require_once "../../controlador/gestiondocumental.controlador.php";

                    // Instancia de la clase controladora ControladorGestionDocumental.
                    $gestionDocumentalControlador = new ControladorGestionDocumental();
                    
                    // Tipos de documentos 
                    $tipoDocumentos = $gestionDocumentalControlador->ctrConsultaTipoDocumento();

                    // Procesos
                    // $procesos = $gestionDocumentalControlador->ctrConsultaProcesos();

                    // Estados de documementos
                    // $estadoDocumentos = $gestionDocumentalControlador->ctrlConsultaEstadoDocumentos();

                    // Lista de documentos
                    // $documentos = $gestionDocumentalControlador->ctrConsultaDocumentos();

                    // Usuarios
                    $usuarios = $gestionDocumentalControlador->ctrlConsultaUsuarios();

                    // Ejecución de la función controladora encargada de consultar perfiles. 
                    $documentos = $gestionDocumentalControlador->ctrConsultaDocumentos_('', '', '', $_GET['id_proceso'], $_GET['id_perfil']);

                    //echo $_GET['id_proceso'];
                    // echo "//".$_GET['id_perfil'];

                   ?>
                  <div class="row">
                    <!-- <button type="button" class="btn btn-success col-sm-12 mb-3" data-toggle="modal" data-target="#id_documento">Crear nuevo documento <i class="fas fa-plus ml-2"></i></button> -->
                    <form class="mb-5 form-horizontal" autocomplete="off" id="frm_busca_documento">

                      <input type="hidden" name="id_proceso_prueba" id="id_proceso_prueba" value="<?php echo $_GET['id_proceso'] ?>">

                      <input type="hidden" name="id_perfil_prueba" id="id_perfil_prueba" value="<?php echo $_GET['id_perfil'] ?>">

                      <div class="form-group col-sm-4">
                        <input type="text" class="form-control text-uppercase" name="nombre" id="nombre" placeholder="NOMBRE" style="height: 30px;">
                      </div>
                      <div class="form-group col-sm-3">
                        <select class="form-control selectperfil" name="tipodocumento_prueba" id="tipodocumento_prueba">
                          <option value="0">TIPO DE DOCUMENTO</option>
                          <?php foreach ($tipoDocumentos as $tipoDocumento) { ?>
                            <option value="<?php echo $tipoDocumento['id'] ?>"><?php echo utf8_encode($tipoDocumento['descripcion']) ?></option>
                          <?php } ?>  
                        </select>
                      </div>
                      <div class="form-group col-sm-3">
                        <select class="form-control selectperfil" name="creador" id="creador">
                          <option value="">CREADO POR</option>
                          <?php foreach ($usuarios as $usuario) { ?>
                            <option value="<?php echo $usuario['id'] ?>"><?php echo utf8_encode($usuario['nombres']).' '.utf8_encode($usuario['apellidos']) ?></option>
                          <?php } ?>  
                        </select>
                      </div>
                      <div class="form-group col-sm-2">
                        <button class="btn btn-success btn-block" type="button" style="height: 33px;" onclick="cargarDocumentos();">Buscar <i class="fas fa-search ml-3"></i></button>
                      </div>
                    </form>  
                    <div class="table-responsive" id="carga_documentos">
                      <table class="table">
                        <thead class="text-left">
                          <tr style="border: none;">
                            <th class="h6 pl-0 pr-0">Id</th>
                            <th class="h6 pl-0 pr-0">Nombre</th>
                            <!-- <th class="h6 pl-0 pr-0">Descripción</th> -->
                            <th class="h6 pl-0 pr-0">Tipo</th>
                            <th class="h6 pl-0 pr-0">Creado por</th>
                            <th class="h6 text-center pl-0 pr-0">Fecha creación</th>
                            <th class="h6 pl-0 pr-0">Visualizar</th>
                          </tr>
                        </thead>
                        <tbody>
                          <?php foreach ($documentos as $documento): ?>
                            <tr>
                              <td class="pl-1 pr-0"><?php echo $documento['id'] ?></td>
                              <td class="pl-1 pr-0"><?php echo utf8_encode($documento['nombre']) ?></td>
                              <!-- <td class="pl-1 pr-0"><?php echo utf8_encode(strtoupper($documento['descripcion'])) ?></td> -->
                              <td class="pl-1 pr-0"><?php echo utf8_encode($documento['desc_tipo_documento']) ?></td>
                              <td class="pl-1 pr-0"><?php echo $documento['nombres'].' '.$documento['apellidos'] ?></td>
                              <td class="pl-1 pr-0"><?php echo $documento['fecha_creacion'] ?></td>
                              <td class="pl-1 pr-0">
                                <a href="http://alejoposada.info/sie/docs/<?php echo $documento['ruta'] ?>" class="btn btn-success text-white" target="_blank"><i class="far fa-file-pdf"></i></a>
                              </td>
                            </tr>
                          <?php endforeach ?>  
                        </tbody>
                      </table>
                    </div>
                  </div>
                </div>
                <!-- /.card-body -->
                <div class="card-footer text-right">
                 
                </div>
              </form>  
              <!-- /.card-footer-->
            </div>
            <!-- /.card -->
          </div>
        </div>
      </div>
    </section>
    <!-- /.content -->
  </div>